@@ -14,7 +14,7 @@
 #' @rdname is_git2rmeta
 #' @export
 #' @family internal
-#' @template example-isgit2r
+#' @template example_isgit2r
 is_git2rmeta <- function(file, root = ".",
                          message = c("none", "warning", "error")) {
   UseMethod("is_git2rmeta", root)
@@ -38,7 +38,11 @@ is_git2rmeta.character <- function(file, root = ".",
   file <- clean_data_path(root = root, file = file)
 
   if (!file.exists(file["meta_file"])) {
-    msg <- "Metadata file missing."
+    msg <- ifelse(
+      file.exists(file["raw_file"]),
+      "Metadata file missing.",
+      "`git2rdata` object not found."
+    )
     switch(message, error = stop(msg, call. = FALSE),
            warning = warning(msg, call. = FALSE))
     return(FALSE)
